<?php

namespace Guru\PushPostback\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use Guru\PushPostback\Http\Requests\PushPostbackAdminApiRequest;
use Guru\PushPostback\Interfaces\PushPostbackRepositoryInterface;
use Guru\PushPostback\Models\PushPostback;

/**
 * Admin API controller class.
 */
class PushPostbackAdminApiController extends AdminController
{
    /**
     * Initialize push_postback controller.
     *
     * @param type PushPostbackRepositoryInterface $push_postback
     *
     * @return type
     */
    public function __construct(PushPostbackRepositoryInterface $push_postback)
    {
        $this->repository = $push_postback;
        parent::__construct();
    }

    /**
     * Display a list of push_postback.
     *
     * @return json
     */
    public function index(PushPostbackAdminApiRequest $request)
    {
        $push_postbacks  = $this->repository
            ->setPresenter('\\Guru\\PushPostback\\Repositories\\Presenter\\PushPostbackListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $push_postbacks['code'] = 2000;
        return response()->json($push_postbacks) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display push_postback.
     *
     * @param Request $request
     * @param Model   PushPostback
     *
     * @return Json
     */
    public function show(PushPostbackAdminApiRequest $request, PushPostback $push_postback)
    {
        $push_postback         = $push_postback->presenter();
        $push_postback['code'] = 2001;
        return response()->json($push_postback)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new push_postback.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(PushPostbackAdminApiRequest $request, PushPostback $push_postback)
    {
        $push_postback         = $push_postback->presenter();
        $push_postback['code'] = 2002;
        return response()->json($push_postback)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new push_postback.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(PushPostbackAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $push_postback          = $this->repository->create($attributes);
            $push_postback          = $push_postback->presenter();
            $push_postback['code']  = 2004;

            return response()->json($push_postback)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show push_postback for editing.
     *
     * @param Request $request
     * @param Model   $push_postback
     *
     * @return json
     */
    public function edit(PushPostbackAdminApiRequest $request, PushPostback $push_postback)
    {
        $push_postback         = $push_postback->presenter();
        $push_postback['code'] = 2003;
        return response()-> json($push_postback)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the push_postback.
     *
     * @param Request $request
     * @param Model   $push_postback
     *
     * @return json
     */
    public function update(PushPostbackAdminApiRequest $request, PushPostback $push_postback)
    {
        try {

            $attributes = $request->all();

            $push_postback->update($attributes);
            $push_postback         = $push_postback->presenter();
            $push_postback['code'] = 2005;

            return response()->json($push_postback)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the push_postback.
     *
     * @param Request $request
     * @param Model   $push_postback
     *
     * @return json
     */
    public function destroy(PushPostbackAdminApiRequest $request, PushPostback $push_postback)
    {

        try {

            $t = $push_postback->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('push_postback::push_postback.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
