<?php

namespace Guru\PushPostback\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Guru\PushPostback\Models\PushPostback;

class PushPostbackPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the push_postback.
     *
     * @param User $user
     * @param PushPostback $push_postback
     *
     * @return bool
     */
    public function view(User $user, PushPostback $push_postback)
    {
        if ($user->canDo('push_postback.push_postback.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $push_postback->user_id;
    }

    /**
     * Determine if the given user can create a push_postback.
     *
     * @param User $user
     * @param PushPostback $push_postback
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('push_postback.push_postback.create');
    }

    /**
     * Determine if the given user can update the given push_postback.
     *
     * @param User $user
     * @param PushPostback $push_postback
     *
     * @return bool
     */
    public function update(User $user, PushPostback $push_postback)
    {
        if ($user->canDo('push_postback.push_postback.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $push_postback->user_id;
    }

    /**
     * Determine if the given user can delete the given push_postback.
     *
     * @param User $user
     * @param PushPostback $push_postback
     *
     * @return bool
     */
    public function destroy(User $user, PushPostback $push_postback)
    {
        if ($user->canDo('push_postback.push_postback.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $push_postback->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
